@@ -31,7 +31,7 @@ setuptools.setup(
     name='gardener-cicd-whd',
     version=version(),
     description='Gardener CI/CD Webhook Dispatcher',
-    python_requires='>=3.10.*',
+    python_requires='>=3.10',
     py_modules=modules(),
     packages=['whd'],
     package_data={
